# Documentation
Visit [docs.myxrobotics.com](https://docs.myxrobotics.com) to see the documentation in your browser.

Generated with:
```sh
$ python3 -m pip install pdoc3
$ python3 -m pdoc --html myx
$ open html/myx/index.html
```
